@@ -321,10 +321,11 @@ def deploy_to_remote():
     project_name = env.project_name
     source_root_name = 'source'
     venv_name = 'venv'
+    log_name = 'logs'
     remote_project_path = os.path.join(remote_base_path, project_name)
-    remote_project_source_root = env.remote_project_source_root =\
-    os.path.join(remote_project_path, source_root_name)
+    remote_project_source_root = env.remote_project_source_root = os.path.join(remote_project_path, source_root_name)
     remote_project_venv = env.remote_project_venv = os.path.join(remote_project_path, venv_name)
+    remote_project_log_root = env.remote_project_log_root = os.path.join(remote_project_path, log_name)
     project_src_root = env.project_src_root
     host_string = env.host_string
     commit_msg = env.commit_msg
@@ -375,6 +376,7 @@ def deploy_to_remote():
         update_apache_conf = True
         # Make room
         target_sudo('mkdir -p %s'%remote_project_path)
+        target_sudo('mkdir -p %s'%remote_project_log_root)
         target_sudo('chown -R %s:%s %s'%(remote_user, remote_group, remote_project_path))
         # Source folder with git
         target_run('mkdir -p %s'%remote_project_source_root)
@@ -440,7 +442,9 @@ def deploy_to_remote():
         for settings_fetch_args in apache_conf_context_keys:
             context_value = deploy_settings.get(*settings_fetch_args)
             apache_conf_context[settings_fetch_args[0].lower()] = context_value
-        apache_conf_context['project_path'] = remote_project_source_root
+        apache_conf_context['project_base_path'] = remote_project_path
+        apache_conf_context['project_log_path'] = remote_project_log_root
+        apache_conf_context['project_source_path'] = remote_project_source_root
         apache_conf_context['wsgi_script_dir_name'] = wsgi_script_dir_name
         apache_conf_context['wsgi_script_file_name'] = wsgi_script_file_name
         # Render Apache conf
