@@ -63,3 +63,6 @@ class AccessKey(models.Model):
             return False
 
         return ~(~required_permission|(required_permission&self.permissions))==0
+
+    def __unicode__(self):
+        return u'Access key for %s'%self.app_id
