@@ -68,17 +68,6 @@ class View(object):
             else:
                 raise MethodNotAllowedError(request)
 
-            # Extend django request query dict
-            if request.method.upper() == 'PUT':
-                if not hasattr(request, 'PUT'):
-                    if DJANGO_VERSION[1] >= 4:
-                        raw_body = self.request.body
-                    else:
-                        raw_body = self.request.raw_post_data
-                    setattr(self.request, request.method.upper(), QueryDict(raw_body))
-            elif request.method.upper() not in ('POST', 'GET'):
-                setattr(self.request, request.method.upper(), self.request.GET)
-
             # Check HTTP Refer
             http_referer = self.request.META.get('HTTP_REFERER', None)
             self.check_http_referer(http_referer, *args, **kwargs)
@@ -104,21 +93,6 @@ class View(object):
 
         return self.response
 
-    # Extend query dict
-    @property
-    def PUT(self):
-        if not hasattr(self, '_put'):
-            if self.request.method.lower()=='put':
-                if DJANGO_VERSION[1] >= 4:
-                    raw_body = self.request.body
-                else:
-                    raw_body = self.request.raw_post_data
-                self._put = QueryDict(raw_body)
-            else:
-                self._put = QueryDict({})
-
-        return self._put
-
     def pre_handle(self, *args, **kwargs):
         pass
 
