@@ -127,8 +127,8 @@ class APIView(View):
             'error': error_obj.message,
         }
         meta = {}
-        if len(error_obj.user_info.items()): meta['user_info'] = error_obj.user_info
-        if len(error_obj.init_kwargs.items()): meta['keyword'] = error_obj.init_kwargs
+        if error_obj.user_info and len(error_obj.user_info.items()): meta['user_info'] = error_obj.user_info
+        if error_obj.init_kwargs and len(error_obj.init_kwargs.items()): meta['keyword'] = error_obj.init_kwargs
 
         try: result['meta'] = json.loads(json.dumps(meta))
         except TypeError: pass
